@@ -1,4 +1,4 @@
-// Copyright (C) 2005 Open Source Telecom Corp.
+// Copyright (C) 2005 David Sugar, Tycho Softworks.
 //  
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -311,6 +311,16 @@ void BayonneSysexec::execute(unsigned ts, const char *cmd)
 
 	diff = dp - path;
 
+	if(ext && (!stricmp(ext, ".exe") || !stricmp(ext, ".il")))
+	{
+		args[0] = PNET_PROGRAM;
+		args[1] = newString(path);
+		args[2] = NULL;
+		argc = 2;
+		setString(path, sizeof(path), PNET_PROGRAM);
+		goto launch;
+	}
+
         if(ext && !stricmp(ext, ".class"))
         {
 		*ext = 0;
