@@ -1132,7 +1132,9 @@ bool BayonneSession::stateJoin(Event *event)
 	return rtn;
 
 part:
-//	clrAudio();	// get on other side of reset timer
+	if(!thread)
+		clrAudio();	// get on other side of reset timer if thread
+
 	if(!scriptEvent(msg))
 		if(!signalScript(SIGNAL_PART))
 			error(emsg);
