@@ -481,7 +481,7 @@ live:
 	commonConfig();
 }
 
-void parseConfig(char **argv)
+bool parseConfig(char **argv)
 {
 	char buffer[64];
 	char path[256];
@@ -812,7 +812,7 @@ skip:
 	if(!script)
 	{
 		runtime.setValue("scripts", keypaths.getLast("scripts"));
-		return;
+		return false;
 	}
 
 	snprintf(path, sizeof(path), "%s", script);
@@ -842,6 +842,7 @@ skip:
 		*ext = 0;
 
 	runtime.setValue("startup", script);
+	return true;
 }		
 
 void dumpConfig(Keydata &keydef)
