@@ -133,6 +133,8 @@ ScriptRuntime()
 			(Check)&Checks::chkTransfer},
 		{"libexec", false, (Method)&Methods::scrLibexec,
 			(Check)&Checks::chkLibexec},
+		{"exec", false, (Method)&Methods::scrLibexec,
+			(Check)&Checks::chkLibexec},
 		{"cleardigits", false, (Method)&Methods::scrCleardigits,
 			(Check)&Checks::chkCleardigits},
 		{"replay", false, (Method)&Methods::scrReplay,
@@ -143,6 +145,8 @@ ScriptRuntime()
 			(Check)&Checks::chkCleardigits},
 		{"prompt", false, (Method)&Methods::scrPrompt,
 			(Check)&Checks::chkPathname},
+		{"speak", false, (Method)&Methods::scrPrompt,
+			(Check)&Checks::chkPathname},
 		{"play", false, (Method)&Methods::scrPlay,
 			(Check)&Checks::chkPathname},
         	{NULL, false, NULL, NULL}};
