@@ -348,7 +348,8 @@ static SERVICE_TABLE_ENTRY services[] =
 static void testing(char **argv)
 {
 	testConfig(*argv);		
-	parseConfig(argv);
+	if(!parseConfig(argv))
+		Script::exec_extensions = "";
 	logging();
 
 	Bayonne::errlog("notice", "testing %s on %s %s; driver=%s, timeslots=%s",
