@@ -322,7 +322,7 @@ void purgedir(const char *dir);
 void loadConfig(void);
 void testConfig(char *argv0);
 void dumpConfig(Keydata &keydef);
-void parseConfig(char **argv);
+bool parseConfig(char **argv);
 
 }
 
